@@ -8,7 +8,6 @@ from evbunpack.const import *
 
 _tick,_val,_max = 0,0,0
 def report_extraction_progress(message,now,total):
-    # Extraction rate display. Figured it'd be less boring to have cool digits rapidly changing on screen...lol
     phases = (' ', '▁', '▂', '▃', '▄', '▅', '▆', '▇', '█')        
     _base  = lambda x:int(math.log2(x) // 10 if x > 0 else 0)
     _hrs   = lambda x:'%.2f' % (x/2**(10*_base(x))) + ('B', 'kB', 'MB', 'GB', 'TB')[_base(x)]
@@ -153,10 +152,10 @@ def completed(generator):
         yield item
 
 if __name__ == "__main__":
-    parser = ArgumentParser(description='Enigma Vitural Box 解包工具')
-    parser.add_argument('--legacy',help='启用兼容模式，适用于老版本封包',action='store_true',default=False)
-    parser.add_argument('file', help='封包 EXE 或外部封包文件路径')
-    parser.add_argument('output', help='保存路径')
+    parser = ArgumentParser(description='Enigma Vitural Box Unpacker')
+    parser.add_argument('--legacy',help='Enable compatibility mode to work with older (6.x) EVB packages',action='store_true',default=False)
+    parser.add_argument('file', help='File to be unpacked')
+    parser.add_argument('output', help='Extract destination directory')
     args = parser.parse_args()
     
     sys.stdout = sys.stderr
@@ -191,10 +190,10 @@ if __name__ == "__main__":
                     arrChunkData = (val for idx,val in enumerate(array.array('I',blkChunkData)) if idx % 3 == 0)
                     # Chunk data comes in 12-bytes rotation: Chunk size (4bytes), Total size (4bytes), Padding (4bytes)
                     # But with the last Chunk size, it does not come with Total size or Padding...
-                    # I'm using array here to quickly filter every 3rd elements unpacked. Which should always give us Chunk size
-                    # Even if the last 8bytes is missing
+                    # Thus filtering only every 3rd elements works. Which should always give us Chunk size
+                    # Even if the last 8 bytes is missing
                     print('...Decompress [ssize=%d, rsize=%d, offset=0x%x, offsetBlk=0x%x]' % (ssize,rsize,fd.tell(),chunks_blk['size']))                    
-                    wsize = write_bytes(fd,output,size=ssize - chunks_blk['size'],chunk_sizes=completed(arrChunkData),chunk_process=decompress)
+                    wsize = write_bytes(fd,output,size=ssize - chunks_blk['size'],chunk_sizes=arrChunkData,chunk_process=decompress)
                     assert wsize == rsize,"Incorrect size"
                 else:
                     print('...Write [size=0x%x, offset=0x%x]' % (ssize,offset))
@@ -209,10 +208,11 @@ if __name__ == "__main__":
     try:
         traverse(next(nodes))
     except StopIteration:                
-        print('[!] 索引创建失败。若解包对象由老版本 Engima Virtual Box 创建，请启用 --legacy 选项')      
+        print('[!] Magic found. But no filetable can be extracted.')
+        print('[!] Try enable / disabling --legacy option to see if that works.')      
         sys.exit(1)
     except AssertionError as e:
-        print('[!] 封包无效',e)
+        print('[!] While extracting package',e)
         sys.exit(1)
     print('[!] Extraction complete',' ' * 20)
     sys.exit(0)
